# oneNueron_pypi
about pakages 

# Reference

[official python docs]:(https://packaging.python.org/tutorials/packaging-projects/)

[github docs for github actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-regestries)